@@ -6,6 +6,7 @@ Relativictic Difference Scheme Particle-in-Cell code (REDPIC) solver file.
 import numpy as np
 import pandas as pd
 from numba import jit, prange
+from multiprocessing import Process
 from scipy import misc
 from .constants import *
 from .beam import *
@@ -73,27 +74,26 @@ def sum_field_particles(x: np.array, y: np.array, z: np.array,
     return Fx, Fy, Fz
 
 def get_field_beam(beam: Beam, acc: Accelerator, type: str,
-                   x: np.array, y: np.array, z: np.array) -> (np.array,
-                                                              np.array,
-                                                              np.array):
+                   x: np.array, y: np.array, z: np.array) -> (np.array, np.array, np.array):
     ''' Get an electric [MV/m] or magnetic [T] field space charge at a specific location in the accelerator
+
     '''
     assert type == 'E' or type == 'B', 'Check type field! (E or B)'
     Q = beam.charge
     q = beam.charge / beam.n
     if type == 'E':
         Ex, Ey, Ez = sum_field_particles(x, y, z, acc.z_start, acc.z_stop)
-        return ke*q*Ex/1e6, ke*q*Ey/1e6, ke*q*Ez/1e6
+        return ke/(4*np.pi)*q*Ex/1e6, ke/(4*np.pi)*q*Ey/1e6, ke/(4*np.pi)*q*Ez/1e6
     if type == 'B':
         Bx, By, Bz = sum_field_particles(x, y, z, acc.z_start, acc.z_stop)
-        return km*q*Bx, -km*q*By, 0*Bz
+        return mu_0/(4*np.pi)*q*Bx, -mu_0/(4*np.pi)*q*By, 0*mu_0/(4*np.pi)*q*Bz
 
 @jit(nopython=True, parallel=True, fastmath=True, cache=True, nogil=True)
 def first_step_red(x: np.array, y: np.array, z: np.array,
                    px: np.array, py: np.array, pz: np.array,
                    Fx: np.array, Fy: np.array, Fz: np.array,
                    z_start: float, z_stop: float) -> (np.array, np.array, np.array,
-                                                       np.array, np.array, np.array):
+                                                      np.array, np.array, np.array):
     ''' First step for Relativictic Difference Scheme
 
     '''
@@ -121,7 +121,7 @@ def second_step_red(x: np.array, y: np.array, z: np.array,
                     px: np.array, py: np.array, pz: np.array,
                     Fx: np.array, Fy: np.array, Fz: np.array,
                     z_start: float, z_stop: float) -> (np.array, np.array, np.array,
-                                                        np.array, np.array, np.array):
+                                                       np.array, np.array, np.array):
     ''' Second step for Relativictic Difference Scheme
 
     '''
@@ -182,7 +182,7 @@ class Simulation:
 
         P0 = m*c*c / (e*1e6)
         E0 = m*c / (q*dt*1e6)
-        B0 = m / (q*dt)  
+        B0 = m / (q*dt)
 
         # RED
         for t in np.arange(0, t_max, 2*dt):
@@ -247,7 +247,8 @@ class Simulation:
                              'Bx', 'By', 'Bz', 'Ex', 'Ey', 'Ez' ])
             file_name = self.beam.type.symbol + 'Beam.'+ '%04.0f' % (meters * 100) +'.csv'
             if progress % (100 // n_files) < 2*dt / t_max * 100:
-                df.to_csv(file_name)
+                writer = Process(target=df.to_csv, args=(file_name,), daemon=True)
+                writer.start()
             print( '\rz = %.2f m (%.1f %%) ' % (meters, progress), end='')
 
 Sim = Simulation
